"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
Object.defineProperty(exports, "__esModule", { value: true });
const type_graphql_1 = require("type-graphql");
const type_1 = require("./type");
const jest_manager_1 = require("../../services/jest-manager");
const project_1 = require("../../services/project");
const cli_1 = require("../../services/cli");
const status_1 = require("./status");
const event_emitter_1 = require("../../event-emitter");
let RunnerResolver = class RunnerResolver {
    constructor() {
        this.isWatching = false;
        this.workspace = new project_1.default(cli_1.root);
        this.jestManager = new jest_manager_1.default(this.workspace);
    }
    getConfig() {
        const runner = new type_1.Runner();
        runner.config = "";
        runner.status = "";
        this.jestManager.getConfig();
        return runner;
    }
    runnerStatus() {
        const status = new status_1.RunnerStatus();
        status.activeFile = this.activeFile;
        status.running = this.isRunning;
        status.watching = this.isWatching;
        return status;
    }
    runnerStatusChange(event) {
        this.isRunning =
            event.payload.isRunning !== undefined
                ? event.payload.isRunning
                : this.isRunning;
        const status = new status_1.RunnerStatus();
        status.activeFile = this.activeFile;
        status.running = this.isRunning;
        status.watching = this.isWatching;
        return status;
    }
    runFile(path, watch) {
        this.activeFile = path;
        if (this.isWatching && this.isRunning) {
            return this.jestManager.switchToAnotherFile(path);
        }
        return this.jestManager.runSingleFile(path, this.isWatching);
    }
    run() {
        this.activeFile = "";
        this.isRunning = true;
        return this.jestManager.run(this.isWatching);
    }
    updateSnapshot(path) {
        return this.jestManager.updateSnapshotToFile(path);
    }
    toggleWatch(watch) {
        this.isWatching = watch;
        event_emitter_1.pubsub.publish(jest_manager_1.RunnerEvents.RUNNER_WATCH_MODE_CHANGE, {
            id: jest_manager_1.RunnerEvents.RUNNER_WATCH_MODE_CHANGE,
            payload: {}
        });
    }
};
__decorate([
    type_graphql_1.Query(returns => type_1.Runner),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], RunnerResolver.prototype, "getConfig", null);
__decorate([
    type_graphql_1.Query(returns => status_1.RunnerStatus),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], RunnerResolver.prototype, "runnerStatus", null);
__decorate([
    type_graphql_1.Subscription(returns => status_1.RunnerStatus, {
        topics: [
            jest_manager_1.RunnerEvents.RUNNER_STARTED,
            jest_manager_1.RunnerEvents.RUNNER_STOPPED,
            jest_manager_1.RunnerEvents.RUNNER_WATCH_MODE_CHANGE
        ]
    }),
    __param(0, type_graphql_1.Root()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", void 0)
], RunnerResolver.prototype, "runnerStatusChange", null);
__decorate([
    type_graphql_1.Mutation(returns => String, { nullable: true }),
    __param(0, type_graphql_1.Arg("path")),
    __param(1, type_graphql_1.Arg("watch", { nullable: true })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Boolean]),
    __metadata("design:returntype", void 0)
], RunnerResolver.prototype, "runFile", null);
__decorate([
    type_graphql_1.Mutation(returns => String, { nullable: true }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], RunnerResolver.prototype, "run", null);
__decorate([
    type_graphql_1.Mutation(returns => String, { nullable: true }),
    __param(0, type_graphql_1.Arg("path")),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], RunnerResolver.prototype, "updateSnapshot", null);
__decorate([
    type_graphql_1.Mutation(returns => status_1.RunnerStatus, { nullable: true }),
    __param(0, type_graphql_1.Arg("watch")),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Boolean]),
    __metadata("design:returntype", void 0)
], RunnerResolver.prototype, "toggleWatch", null);
RunnerResolver = __decorate([
    type_graphql_1.Resolver(type_1.Runner),
    __metadata("design:paramtypes", [])
], RunnerResolver);
exports.default = RunnerResolver;
//# sourceMappingURL=resolver.js.map