"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
var __param = (this && this.__param) || function (paramIndex, decorator) {
    return function (target, key) { decorator(target, key, paramIndex); }
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const type_graphql_1 = require("type-graphql");
const workspace_1 = require("./workspace");
const project_1 = require("../../services/project");
const cli_1 = require("../../services/cli");
const jest_manager_1 = require("../../services/jest-manager");
const test_file_1 = require("./test-file");
const inspector_1 = require("../../services/ast/inspector");
const file_result_1 = require("./test-result/file-result");
const result_handler_api_1 = require("../../services/result-handler-api");
const results_1 = require("../../services/results");
const file_watcher_1 = require("../../services/file-watcher");
const summary_1 = require("./summary");
const event_emitter_1 = require("../../event-emitter");
let WorkspaceResolver = class WorkspaceResolver {
    constructor() {
        this.project = new project_1.default(cli_1.root);
        this.jestManager = new jest_manager_1.default(this.project);
        this.results = new results_1.default();
        event_emitter_1.pubsub.subscribe(result_handler_api_1.Events.TEST_RESULT, event => {
            const payload = event.payload;
            const result = new file_result_1.TestFileResult();
            result.path = payload.path;
            const testResult = payload.result.testResult;
            result.failureMessage = testResult.failureMessage;
            result.numPassingTests = testResult.numPassingTests;
            result.numFailingTests = testResult.numFailingTests;
            result.numPendingTests = testResult.numPendingTests;
            result.testResults = testResult.testResults;
            this.results.setTestReport(payload.path, result);
        });
    }
    workspace() {
        const workspace = new workspace_1.Workspace();
        workspace.projectRoot = this.project.projectRoot;
        workspace.name = "Jest project";
        const jestConfig = this.jestManager.getConfig();
        const fileMap = this.project.readTestFiles(jestConfig);
        workspace.files = Object.entries(fileMap).map(([key, value]) => ({
            name: value.name,
            path: value.path,
            parent: value.parent,
            type: value.type
        }));
        return workspace;
    }
    toggleFile(path, isExpanded) {
        return this.project.toggleItem(path, isExpanded);
    }
    file(path) {
        const file = new test_file_1.TestFile();
        file.items = inspector_1.inspect(path);
        return file;
    }
    result(path) {
        const result = this.results.getResult(path);
        return result ? result.report : null;
    }
    fileChange(event, path) {
        const file = new test_file_1.TestFile();
        file.items = inspector_1.inspect(event.payload.path);
        return file;
    }
    changeToResult(event, path) {
        return __awaiter(this, void 0, void 0, function* () {
            const payload = event.payload;
            const result = new file_result_1.TestFileResult();
            result.path = path;
            if (event.id === result_handler_api_1.Events.TEST_RESULT) {
                const testResult = payload.result.testResult;
                result.path = payload.path;
                result.failureMessage = testResult.failureMessage;
                result.numPassingTests = testResult.numPassingTests;
                result.numFailingTests = testResult.numFailingTests;
                result.numPendingTests = testResult.numPendingTests;
                result.testResults = testResult.testResults;
            }
            return result;
        });
    }
    changeToSummary(event) {
        return __awaiter(this, void 0, void 0, function* () {
            const { numFailedTests, numPassedTests, numPassedTestSuites, numFailedTestSuites } = event.payload.summary;
            const summary = new summary_1.Summary();
            summary.numFailedTests = numFailedTests;
            summary.numPassedTests = numPassedTests;
            summary.numPassedTestSuites = numPassedTestSuites;
            summary.numFailedTestSuites = numFailedTestSuites;
            this.results.setSummary(numPassedTests, numFailedTests, numPassedTestSuites, numFailedTestSuites);
            return summary;
        });
    }
    summary() {
        const { numFailedTests, numPassedTests, numPassedTestSuites, numFailedTestSuites } = this.results.getSummary();
        const result = new summary_1.Summary();
        result.numFailedTests = numFailedTests;
        result.numPassedTests = numPassedTests;
        result.numFailedTestSuites = numFailedTestSuites;
        return result;
    }
};
__decorate([
    type_graphql_1.Query(returns => workspace_1.Workspace),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], WorkspaceResolver.prototype, "workspace", null);
__decorate([
    type_graphql_1.Mutation(returns => String),
    __param(0, type_graphql_1.Arg("path")),
    __param(1, type_graphql_1.Arg("isExpanded")),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, Boolean]),
    __metadata("design:returntype", void 0)
], WorkspaceResolver.prototype, "toggleFile", null);
__decorate([
    type_graphql_1.Query(returns => test_file_1.TestFile),
    __param(0, type_graphql_1.Arg("path")),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], WorkspaceResolver.prototype, "file", null);
__decorate([
    type_graphql_1.Query(returns => file_result_1.TestFileResult, { nullable: true }),
    __param(0, type_graphql_1.Arg("path")),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", void 0)
], WorkspaceResolver.prototype, "result", null);
__decorate([
    type_graphql_1.Subscription(returns => test_file_1.TestFile, {
        topics: [file_watcher_1.WatcherEvents.FILE_CHANGE]
    }),
    __param(0, type_graphql_1.Root()), __param(1, type_graphql_1.Arg("path")),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, String]),
    __metadata("design:returntype", void 0)
], WorkspaceResolver.prototype, "fileChange", null);
__decorate([
    type_graphql_1.Subscription(returns => file_result_1.TestFileResult, {
        topics: [result_handler_api_1.Events.TEST_START, result_handler_api_1.Events.TEST_RESULT],
        filter: ({ payload: { payload }, args }) => {
            return payload.path === args.path;
        }
    }),
    __param(0, type_graphql_1.Root()),
    __param(1, type_graphql_1.Arg("path")),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object, String]),
    __metadata("design:returntype", Promise)
], WorkspaceResolver.prototype, "changeToResult", null);
__decorate([
    type_graphql_1.Subscription(returns => summary_1.Summary, {
        topics: [result_handler_api_1.Events.RUN_SUMMARY]
    }),
    __param(0, type_graphql_1.Root()),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Object]),
    __metadata("design:returntype", Promise)
], WorkspaceResolver.prototype, "changeToSummary", null);
__decorate([
    type_graphql_1.Query(returns => summary_1.Summary, { nullable: true }),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], WorkspaceResolver.prototype, "summary", null);
WorkspaceResolver = __decorate([
    type_graphql_1.Resolver(workspace_1.Workspace),
    __metadata("design:paramtypes", [])
], WorkspaceResolver);
exports.default = WorkspaceResolver;
//# sourceMappingURL=resolver.js.map