"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const traverse_1 = require("@babel/traverse");
const nanoid = require("nanoid");
const parser_1 = require("./parser");
const fs_1 = require("fs");
function inspect(path) {
    const code = fs_1.readFileSync(path, "utf8");
    const ast = parser_1.parse(code);
    const result = [];
    traverse_1.default(ast, {
        CallExpression(path) {
            if (path.scope.block.type === "Program") {
                findItems(path, result);
            }
        }
    });
    return result;
}
exports.inspect = inspect;
function findItems(path, result) {
    findDescribes(path, result);
    findTests(path, result);
}
function findDescribes(path, result) {
    if (path.node.callee.name === "describe") {
        const describe = {
            id: nanoid(),
            type: "describe",
            name: path.node.arguments[0].value
        };
        result.push(describe);
        path.traverse({
            CallExpression(itPath) {
                findTests(itPath, result, describe.id);
            }
        });
    }
}
function findTests(path, result, parentId) {
    if (path.node.callee.name === "it" || path.node.callee.name === "test") {
        result.push({
            type: "it",
            name: path.node.arguments[0].value,
            id: nanoid(),
            parent: parentId
        });
    }
}
//# sourceMappingURL=inspector.js.map