"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const child_process_1 = require("child_process");
const path_1 = require("path");
const resolvePkg = require("resolve-pkg");
const cli_args_1 = require("./cli-args");
const event_emitter_1 = require("../../event-emitter");
exports.RunnerEvents = {
    RUNNER_STARTED: "RunnerStarted",
    RUNNER_STOPPED: "RunnerStopped",
    RUNNER_WATCH_MODE_CHANGE: "WatchModeChanged"
};
class JestManager {
    constructor(project) {
        this.project = project;
    }
    getJestScriptPath() {
        const path = resolvePkg("jest", {
            cwd: this.project.projectRoot
        });
        return path_1.join(path, "bin/jest.js");
    }
    getConfig() {
        const process = this.executeJestSync([cli_args_1.ShowConfig]);
        const configStr = process.stdout.toString().trim();
        const config = JSON.parse(configStr);
        return config;
    }
    run(watch) {
        this.executeJest([
            "--reporters",
            this.getRepoterPath(),
            ...(watch ? ["--watch"] : [])
        ]);
    }
    runSingleFile(path, watch) {
        this.executeJest([
            this.getPatternForPath(path),
            ...(watch ? ["--watch"] : []),
            "--reporters",
            this.getRepoterPath()
        ]);
    }
    updateSnapshotToFile(path) {
        this.executeJest([
            this.getPatternForPath(path),
            "-u",
            "--reporters",
            this.getRepoterPath()
        ]);
    }
    switchToAnotherFile(path) {
        this.executeInSequence([
            {
                fn: () => this.process.stdin.write("p"),
                delay: 0
            },
            {
                fn: () => this.process.stdin.write(this.getPatternForPath(path)),
                delay: 100
            },
            {
                fn: () => this.process.stdin.write(new Buffer("0d", "hex").toString()),
                delay: 200
            }
        ]);
    }
    executeJest(args) {
        this.reportStart();
        this.process = child_process_1.spawn(`node -r ${this.getPatchFilePath()} ${this.getJestScriptPath()}`, args, {
            cwd: this.project.projectRoot,
            shell: true,
            stdio: "pipe",
            env: {}
        });
        this.process.on("close", () => {
            this.reportStop();
        });
    }
    getRepoterPath() {
        return path_1.join(__dirname, "./scripts/reporter.js");
    }
    getPatchFilePath() {
        return path_1.join(__dirname, "./scripts/patch.js");
    }
    getPatternForPath(path) {
        let replacePattern = /\//g;
        if (process.platform === "win32") {
            replacePattern = /\\/g;
        }
        return `^${path.replace(replacePattern, ".")}$`;
    }
    executeJestSync(args) {
        return child_process_1.spawnSync(`node ${this.getJestScriptPath()}`, args, {
            cwd: this.project.projectRoot,
            shell: true,
            stdio: "pipe",
            env: {}
        });
    }
    reportStart() {
        event_emitter_1.pubsub.publish(exports.RunnerEvents.RUNNER_STARTED, {
            id: exports.RunnerEvents.RUNNER_STARTED,
            payload: {
                isRunning: true
            }
        });
    }
    reportStop() {
        event_emitter_1.pubsub.publish(exports.RunnerEvents.RUNNER_STOPPED, {
            id: exports.RunnerEvents.RUNNER_STOPPED,
            payload: {
                isRunning: false
            }
        });
    }
    executeInSequence(funcs) {
        return __awaiter(this, void 0, void 0, function* () {
            for (const { fn, delay } of funcs) {
                yield this.setTimeoutPromisify(fn, delay);
            }
        });
    }
    setTimeoutPromisify(fn, delay) {
        return new Promise(resolve => {
            setTimeout(() => {
                fn();
                resolve();
            }, delay);
        });
    }
}
exports.default = JestManager;
//# sourceMappingURL=index.js.map