"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const directoryTree = require("directory-tree");
const micromatch = require("micromatch");
class Project {
    constructor(root) {
        this.expandedItems = {};
        this.readTestFiles = (jestConfig) => {
            this.testFileMatcher = this.getTestFileMatcher(jestConfig);
            const files = directoryTree(this.projectRoot, {
                exclude: /node_modules|\.git/
            });
            return this.filterTestFiles(files, {});
        };
        /**
         * Filters only the test files
         */
        this.filterTestFiles = ({ name, path, type, children }, map, parent) => {
            if ((type === "directory" &&
                this.hasATestFile({ name, path, type, children })) ||
                (type === "file" && this.testFileMatcher(path))) {
                map[path] = {
                    name,
                    type,
                    path,
                    parent
                };
            }
            children &&
                children.forEach(child => {
                    this.filterTestFiles(child, map, path);
                });
            return map;
        };
        /**
         * Checks if a directory has a test file in it.
         */
        this.hasATestFile = ({ children, type, path }) => {
            if (type === "file" && this.testFileMatcher(path)) {
                return true;
            }
            if (children) {
                return children.some(this.hasATestFile);
            }
            return false;
        };
        this.projectRoot = root;
    }
    toggleItem(path, isExpaned) {
        if (isExpaned) {
            this.expandedItems[path] = true;
        }
        else {
            delete this.expandedItems[path];
        }
    }
    /**
     * Returns a function which checks if a function is a test file
     * @param config
     */
    getTestFileMatcher(config) {
        // TODO: figure out how to deal with multiple values in the config array
        const matchers = config.configs[0].testMatch.map(each => micromatch.matcher(each, { dot: true }));
        return (path) => {
            return matchers.some(each => each(path));
        };
    }
}
exports.default = Project;
//# sourceMappingURL=project.js.map